@@ -4,9 +4,10 @@ public class TestSqlRender {
 
 	public static void main(String[] args) {
 		
-		String sql = "--HINT DISTRIBUTE_ON_KEY(analysis_id)\nCREATE TABLE results.achilles_results_dist";
-		for (String part : SqlSplit.splitSql(sql))
-			System.out.println(part);
+		String sql = "CONCAT( CONCAT( field1, ' and ' ), field2 )";
+		String path = "inst/csv/replacementPatterns.csv";
+		sql = SqlTranslate.translateSqlWithPath(sql, "netezza", null, null, path);
+		System.out.println(sql);
 		
 //		Pattern pattern = Pattern.compile("^((?!FROM).)*$");
 //		System.out.println(pattern.matcher("SELECT * blaat b;").matches());
@@ -14,7 +15,7 @@ public class TestSqlRender {
 //		String sql = "SELECT * FROM table {@a = true} ?  {WHERE name = '@name'};";
 //		sql = SqlRender.renderSql(sql, new String[]{"name", "a"}, new String[]{"NA\\joe", "true"});
 //		System.out.println(sql);	
-//		String path = "inst/csv/replacementPatterns.csv";
+//		
 //		String sourceSql = "SELECT TOP 10 * FROM my_table WHERE a = b;";
 //		String sql;
 //		sql = SqlTranslate.translateSqlWithPath(sourceSql, "postgresql", null, null, path);
